@@ -25,13 +25,17 @@ class AccountInfo(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _AccountType: 账号类型
+        :param _AccountType: 用户账号类型（默认开通QQopenid、手机号MD5；如需使用微信开放账号，则需要"提交工单"或联系对接人进行资格审核，审核通过后方可正常使用微信开放账号）
+1：QQ开放账号
+2：微信开放账号
+8：设备号（imei/imeiMD5/idfa/idfaMd5）
+10004：手机号MD5，中国大陆11位手机号进行MD5加密，取32位小写值
         :type AccountType: int
         :param _QQAccount: QQ账号信息，AccountType是1时，该字段必填。
         :type QQAccount: :class:`tencentcloud.rce.v20201103.models.QQAccountInfo`
         :param _WeChatAccount: 微信账号信息，AccountType是2时，该字段必填。
         :type WeChatAccount: :class:`tencentcloud.rce.v20201103.models.WeChatAccountInfo`
-        :param _OtherAccount: 其它账号信息，AccountType是0、4、8或10004时，该字段必填。
+        :param _OtherAccount: 其它账号信息，AccountType是8或10004时，该字段必填。
         :type OtherAccount: :class:`tencentcloud.rce.v20201103.models.OtherAccountInfo`
         """
         self._AccountType = None
@@ -404,30 +408,28 @@ class InputManageMarketingRisk(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _Account: 用户账号类型（默认开通 QQ 开放账号、手机号，手机 MD5 账号类型查询。如需使用微
-信开放账号，则需要 提交工单 由腾讯云进行资格审核，审核通过后方可正常使用微信
-开放账号）： 
-1：QQ 开放账号。 
-2：微信开放账号。 
-4：手机号（暂仅支持国内手机号）。 
-8：设备号（imei/imeiMD5/idfa/idfaMd5）。 
-0： 其他。 
-10004：手机号 MD5。
-
+        :param _Account: 用户账号类型（默认开通 QQ 开放账号，手机 MD5 账号类型查询。如需使用微信开放账号，则需要 提交工单 由腾讯云进行资格审核，审核通过后方可正常使用微信开放账号）： 
+1：QQ 开放账号；
+2：微信开放账号；
+8：设备号（imei/imeiMD5/idfa/idfaMd5）；
+10004：手机号 MD5。
         :type Account: :class:`tencentcloud.rce.v20201103.models.AccountInfo`
-        :param _SceneCode: 场景类型：场景SceneCode, 控制台上新建对应的场景并获取对应的值；
-例如：e_register_protection_1521184361
-控制台链接：https://console.cloud.tencent.com/rce/risk/sceneroot；
+        :param _SceneCode: 场景码，用于识别和区分不同的业务场景，可在控制台上新建和管理
+控制台链接：https://console.cloud.tencent.com/rce/risk/strategy/scene-root
+活动防刷默认场景码：e_activity_antirush 
+登陆保护默认场景码：e_login_protection
+注册保护默认场景码：e_register_protection
         :type SceneCode: str
-        :param _UserIp: 登录来源的外网IP
+        :param _UserIp: 用户外网ip（传入用户非外网ip会影响判断结果）。
         :type UserIp: str
-        :param _PostTime: 时间戳
+        :param _PostTime: 用户操作时间戳，精确到秒。
         :type PostTime: int
-        :param _UserId: 用户唯一标识。
+        :param _UserId: 业务平台用户唯一标识。
         :type UserId: str
-        :param _DeviceToken: 设备指纹token。
+        :param _DeviceToken: 设备指纹Devicetoken值，集成设备指纹后获取，
+如果集成了相应的设备指纹，该字段必填。
         :type DeviceToken: str
-        :param _DeviceBusinessId: 设备指纹BusinessId
+        :param _DeviceBusinessId: 设备指纹 BusinessId。
         :type DeviceBusinessId: int
         :param _BusinessId: 业务ID。网站或应用在多个业务中使用此服务，通过此ID区分统计数据。
         :type BusinessId: int
@@ -451,23 +453,22 @@ class InputManageMarketingRisk(AbstractModel):
         :type MacAddress: str
         :param _VendorId: 手机制造商ID，如果手机注册，请带上此信息。
         :type VendorId: str
-        :param _DeviceType: 设备类型，账号类型为8时必填： 
-0:未知 
-1:Imei;国际移动设备识别号（15-17位数字） 
-2:ImeiMd5；国际移动设备识别号，通过MD5加密后32位的小写字符串 
-3:Idfa; 
-4:IdfaMD5;
+        :param _DeviceType: 设备类型，账号类型（AccountType）为8时填写。
+1:Imei；国际移动设备识别号（15-17位数字）；
+2:ImeiMd5；国际移动设备识别号，通过MD5加密后取32位小写值；
+3:Idfa；
+4:IdfaMD5； 国际移动设备识别号，通过MD5加密后取32位小写值。
         :type DeviceType: int
-        :param _Details: 详细信息
+        :param _Details: 扩展字段。
         :type Details: list of InputDetails
-        :param _Sponsor: 可选填写。详情请跳转至SponsorInfo查看。
+        :param _Sponsor: 邀请助力场景相关信息。
         :type Sponsor: :class:`tencentcloud.rce.v20201103.models.SponsorInfo`
-        :param _OnlineScam: 可选填写。详情请跳转至OnlineScamInfo查看。
+        :param _OnlineScam: 详情请跳转至OnlineScamInfo查看。
         :type OnlineScam: :class:`tencentcloud.rce.v20201103.models.OnlineScamInfo`
-        :param _Platform: 1：安卓
-2：iOS 
-3：H5 
-4：小程序 
+        :param _Platform: 1：安卓；
+2：iOS ；
+3：H5 ；
+4：小程序 。
 
         :type Platform: str
         """
@@ -895,22 +896,16 @@ class OtherAccountInfo(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _AccountId: 其它账号信息：  
-AccountType 是 4 时，填入真实的手机号（如 13123456789）。 
-AccountType 是 8 时，支持 imei、idfa、imeiMD5、idfaMD5入参。  
-AccountType 是 0 时，填入账号信息。  
-AccountType 是 10004 时，填入手机号的 MD5 值。 
-注：imeiMd5 加密方式为：  
-imei 明文小写后，进行 MD5 加密，加密后取小写值。  
-IdfaMd5 加密方式为：idfa 明文大写后，进行 MD5 加密，加密后取小写值。
-
+        :param _AccountId: 其他账号信息；
+AccountType是8时，填入设备号（imei/imeimd5/idfa/idfamd5）
+AccountType是10004时，填入中国大陆标准11位手机号的MD5值
+注释：
+MD5手机号加密方式，中国大陆11位手机号进行MD5加密，加密后取32位小写值
+imeiMD5/IdfaMd5加密方式，对imei/IdfaMd5明文进行MD5加密，加密后取32位小写值。
         :type AccountId: str
-        :param _MobilePhone: 手机号，若 AccountType 是 4（手机号）、或 10004（手机号 MD5），则无需重复填写 
-否则填入对应的手机号（如 13123456789）。
+        :param _MobilePhone: MD5手机号,AccountType是10004时，此处无需重复填写。
         :type MobilePhone: str
-        :param _DeviceId: 用户设备号。若 AccountType 是 8（设备号），则无需重复填写，否则填入对应的设备 
-号。 
-
+        :param _DeviceId: 用户设备号，AccountType是8时，此处无需重复填写。
         :type DeviceId: str
         """
         self._AccountId = None
@@ -1205,25 +1200,23 @@ class OutputManageMarketingRiskValue(AbstractModel):
         :param _UserId: 账号ID。对应输入参数：
 AccountType是1时，对应QQ的OpenID。
 AccountType是2时，对应微信的OpenID/UnionID。
-AccountType是4时，对应手机号。
 AccountType是8时，对应imei、idfa、imeiMD5或者idfaMD5。
-AccountType是0时，对应账号信息。
 AccountType是10004时，对应手机号的MD5。
 注意：此字段可能返回 null，表示取不到有效值。
         :type UserId: str
         :param _PostTime: 操作时间戳，单位秒（对应输入参数）。
 注意：此字段可能返回 null，表示取不到有效值。
         :type PostTime: int
-        :param _AssociateAccount: 对应输入参数，AccountType 是 QQ 或微信开放账号时，用于标识 QQ 或微信用户登录后关联业务自身的账号ID。
+        :param _AssociateAccount: 业务参数。
 注意：此字段可能返回 null，表示取不到有效值。
         :type AssociateAccount: str
         :param _UserIp: 操作来源的外网IP（对应输入参数）。
 注意：此字段可能返回 null，表示取不到有效值。
         :type UserIp: str
-        :param _RiskLevel: 风险值
-pass : 无恶意
-review：需要人工审核
-reject：拒绝，高风险恶意
+        :param _RiskLevel: 风险等级
+pass：无恶意
+review：低风险，需要人工审核
+reject：高风险，建议拦截
 注意：此字段可能返回 null，表示取不到有效值。
         :type RiskLevel: str
         :param _RiskType: 风险类型，请参考官网风险类型
@@ -1254,9 +1247,12 @@ reject：拒绝，高风险恶意
 2063 疑似 群控设备 请求设备为猫池、手机墙等群控设备
 注意：此字段可能返回 null，表示取不到有效值。
         :type RiskType: list of int
-        :param _ConstId: 唯一ID
+        :param _ConstId: 设备指纹ID，如果集成了设备指纹，并传入了正确的DeviceToken和Platform，该字段正常输出；如果DeviceToken异常（校验不通过），则会在RiskType中返回"-1"标签，ConstId字段为空；如果没有集成设备指纹ConstId字段默认为空。
 注意：此字段可能返回 null，表示取不到有效值。
         :type ConstId: str
+        :param _RiskInformation: 风险扩展数据。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RiskInformation: str
         """
         self._UserId = None
         self._PostTime = None
@@ -1265,6 +1261,7 @@ reject：拒绝，高风险恶意
         self._RiskLevel = None
         self._RiskType = None
         self._ConstId = None
+        self._RiskInformation = None
 
     @property
     def UserId(self):
@@ -1322,6 +1319,14 @@ reject：拒绝，高风险恶意
     def ConstId(self, ConstId):
         self._ConstId = ConstId
 
+    @property
+    def RiskInformation(self):
+        return self._RiskInformation
+
+    @RiskInformation.setter
+    def RiskInformation(self, RiskInformation):
+        self._RiskInformation = RiskInformation
+
 
     def _deserialize(self, params):
         self._UserId = params.get("UserId")
@@ -1331,6 +1336,7 @@ reject：拒绝，高风险恶意
         self._RiskLevel = params.get("RiskLevel")
         self._RiskType = params.get("RiskType")
         self._ConstId = params.get("ConstId")
+        self._RiskInformation = params.get("RiskInformation")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -1354,9 +1360,11 @@ class QQAccountInfo(AbstractModel):
         :type AppIdUser: str
         :param _AssociateAccount: 用于标识QQ用户登录后所关联业务自身的账号ID。
         :type AssociateAccount: str
-        :param _MobilePhone: 账号绑定的手机号。
+        :param _MobilePhone: 账号绑定的MD5手机号，
+注释：只支中国大陆11位手机号MD5加密后位的32位小写字符串。
         :type MobilePhone: str
-        :param _DeviceId: 用户设备号。
+        :param _DeviceId: 用户设备号，支持imei/imeiMD5/Idfa/IdfaMd5
+注释：imeiMD5/IdfaMd5加密方式，对imei/IdfaMd5明文进行MD5加密，加密后取32位小写值。
         :type DeviceId: str
         """
         self._QQOpenId = None
@@ -1429,15 +1437,15 @@ class SponsorInfo(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _SponsorOpenId: OpenID
+        :param _SponsorOpenId: 助力场景建议填写：活动发起人微信 OpenID
         :type SponsorOpenId: str
-        :param _SponsorDeviceNumber: 设备号
+        :param _SponsorDeviceNumber: 助力场景建议填写：发起人设备号
         :type SponsorDeviceNumber: str
-        :param _SponsorPhone: 手机号
+        :param _SponsorPhone: 助力场景建议填写：发起人的MD5手机号
         :type SponsorPhone: str
-        :param _SponsorIp: IP
+        :param _SponsorIp: 助力场景建议填写：发起人IP
         :type SponsorIp: str
-        :param _CampaignUrl: 链接
+        :param _CampaignUrl: 助力场景建议填写：活动链接
         :type CampaignUrl: str
         """
         self._SponsorOpenId = None
@@ -1518,13 +1526,16 @@ class WeChatAccountInfo(AbstractModel):
         :type WeChatSubType: int
         :param _RandStr: 随机串。如果WeChatSubType是2，该字段必填。Token签名随机数，建议16个字符。
         :type RandStr: str
-        :param _WeChatAccessToken: token
+        :param _WeChatAccessToken: 如果WeChatSubType 是1，填入授权的 access_token（注意：不是普通 access_token，详情请参阅官方说明文档。获取网页版本的 access_token 时，scope 字段必需填写snsapi_userinfo
+如果WeChatSubType是2，填入以session_key 为密钥签名随机数RandStr（hmac_sha256签名算法）得到的字符串。
         :type WeChatAccessToken: str
         :param _AssociateAccount: 用于标识微信用户登录后所关联业务自身的账号ID。
         :type AssociateAccount: str
-        :param _MobilePhone: 账号绑定的手机号。
+        :param _MobilePhone: 账号绑定的MD5手机号，
+注释：只支持标准中国大陆11位手机号MD5加密后位的32位小写字符串。
         :type MobilePhone: str
-        :param _DeviceId: 用户设备号。
+        :param _DeviceId: 用户设备号，支持imei/imeiMD5/Idfa/IdfaMd5
+注释：imeiMD5/IdfaMd5加密方式，对imei/IdfaMd5明文进行MD5加密，加密后取32位小写值。
         :type DeviceId: str
         """
         self._WeChatOpenId = None
